extend_audit_batch

Function extend_audit_batch 

pub fn extend_audit_batch(
    partition: &Partition,
    batch: &mut Batch,
    get: impl FnMut(&Key) -> Result<Option<Value>, StoreError>,
) -> Result<(), StoreError>
Extend an existing relay target transaction using reads from that transaction. Dedup receipts, gapless chain entries, and relay watermarks commit atomically.

Errors

Malformed events, changed receipts, or corrupt/unavailable audit metadata.