#[non_exhaustive]pub enum HookConfigError {
SignerRequired,
UnsignedOrigin,
ChannelAudience,
Audience(&'static str),
}Expand description
A refused adapter configuration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SignerRequired
A channel that is not an isolated service binding must sign (SPEC-SERVER 7.1 versus 7.3).
UnsignedOrigin
An unsigned channel is a service binding, which has no origin.
ChannelAudience
Signing binds the hook endpoint’s canonical origin, so the channel must name one.
Audience(&'static str)
The named origin is not a canonical HTTP(S) origin, or is plain HTTP to a host that is not loopback (SPEC-SERVER 6.1).