#[non_exhaustive]pub enum SignerError {
KeyId,
Validity,
Clock,
}Expand description
A signer setting the spec refuses.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KeyId
A key id must be 1-64 bytes of [A-Za-z0-9._-].
Validity
The validity interval must be positive and at most 300,000 ms.
Clock
The clock reads before the epoch, which no header can express.