pub fn key_document(config: &UrlTokenConfig, method: &str) -> HttpObjectResponseExpand description
Serve active and retained public keys without any bearer or payment check.
pub fn key_document(config: &UrlTokenConfig, method: &str) -> HttpObjectResponseServe active and retained public keys without any bearer or payment check.