pub fn missing_base(
now_ms: u64,
created_at_ms: u64,
bound_ms: u64,
) -> ServerErrorExpand description
Exact error for an unresolved base, independent of global blob existence.
pub fn missing_base(
now_ms: u64,
created_at_ms: u64,
bound_ms: u64,
) -> ServerErrorExact error for an unresolved base, independent of global blob existence.