#[non_exhaustive]pub struct RevokeBudget {
pub max_elapsed_ms: u64,
}Expand description
One revocation slice processes at most four shards, within this time budget.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_elapsed_ms: u64Milliseconds of elapsed pipeline time allowed between store calls.
Implementations