#[non_exhaustive]pub enum NamespacePolicy {
Allowlist(BTreeSet<Namespace>),
Any {
unsafe_without_admission: bool,
},
}Expand description
Namespaces served for writes (SPEC-TRANSPORT-CONNECT 7.5). A denial cannot be overridden by an authorizer (SPEC-SERVER 6.2).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Allowlist(BTreeSet<Namespace>)
Only these owner namespaces may receive writes. The default is empty.
Any
Every self-certifying namespace may receive writes. D27 requires non-default admission unless the operator explicitly accepts the risk.