#[non_exhaustive]pub enum FrameIoError {
Eof,
Timeout,
Malformed,
Io(Redacted),
}Expand description
Why a frame could not be read or written.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Eof
The peer closed the stream cleanly, between frames.
Timeout
The source’s read deadline passed.
Malformed
A frame that is too long, truncated or undecodable.
Io(Redacted)
Any other I/O failure; the detail is for the server log only.