pub fn decode_namespace_view(value: &Value) -> Result<NamespaceView, StoreError>Expand description
Decode a view and reject a contribution larger than the aggregate.
pub fn decode_namespace_view(value: &Value) -> Result<NamespaceView, StoreError>Decode a view and reject a contribution larger than the aggregate.