pub fn decode_relay(value: &Value) -> Result<RelayV1, StoreError>Expand description
Decode a relay target and its bounded idempotent operations.
pub fn decode_relay(value: &Value) -> Result<RelayV1, StoreError>Decode a relay target and its bounded idempotent operations.