pub fn decode_relay_scan(value: &Value) -> Result<RelayScanV1, StoreError>Expand description
Decode source relay scan progress, rejecting malformed or unbounded state.
pub fn decode_relay_scan(value: &Value) -> Result<RelayScanV1, StoreError>Decode source relay scan progress, rejecting malformed or unbounded state.