pub fn encode_namespace_view(view: NamespaceView) -> ValueExpand description
Three usage fields and a read timestamp, each big-endian u64.
pub fn encode_namespace_view(view: NamespaceView) -> ValueThree usage fields and a read timestamp, each big-endian u64.