pub struct BackupStateV1 {
pub last_export_ms: u64,
pub digest: Hash,
pub r2_key: String,
pub last_upload_ms: u64,
}Expand description
The last consistent Worker snapshot of one partition. A zero export time and empty key mark a timer that has been seeded but has not fired yet.
Fields
last_export_ms: u64Export time encoded in the last uploaded snapshot, Unix milliseconds.
digest: HashBLAKE3 of the last uploaded portable export.
r2_key: StringR2 object key of the last upload.
last_upload_ms: u64Time of the last successful upload, Unix milliseconds.