pub async fn export_header<S: NamespaceStore>(
store: &S,
p: &Partition,
now_ms: u64,
) -> Result<ExportHeader, StoreError>Expand description
The header of an export of p taken at now_ms.
pub async fn export_header<S: NamespaceStore>(
store: &S,
p: &Partition,
now_ms: u64,
) -> Result<ExportHeader, StoreError>The header of an export of p taken at now_ms.