pub trait PublishedSource: MaybeSend + MaybeSync {
// Required methods
fn inspection_configured(&self) -> bool;
fn bucket<'a>(
&'a self,
repo: &'a RepoId,
partition: &'a Partition,
now_ms: u64,
) -> BoxFuture<'a, PublishedBucket>;
// Provided methods
fn uses_published_values(&self) -> bool { ... }
fn read_ref_enabled(&self) -> bool { ... }
}Expand description
Ref data only: the pipeline authorizes each request before invoking this seam.
Required Methods
Sourcefn inspection_configured(&self) -> bool
fn inspection_configured(&self) -> bool
Whether the deployment configures inspection.
Provided Methods
Sourcefn uses_published_values(&self) -> bool
fn uses_published_values(&self) -> bool
Whether inputs contain exclusively published values, using the current snapshot format.
Sourcefn read_ref_enabled(&self) -> bool
fn read_ref_enabled(&self) -> bool
Optional unsigned ReadRef acceleration; false by default.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".