pub struct PurgeDelivery { /* private fields */ }Expand description
Kind-11 retries immutable work until local and global acknowledgement.
Implementations
Sourceimpl PurgeDelivery
impl PurgeDelivery
Sourcepub fn new(
local: Arc<dyn LocalInvalidation>,
sink: Option<Arc<dyn PurgeSink>>,
budget: SliceBudget,
) -> Self
pub fn new( local: Arc<dyn LocalInvalidation>, sink: Option<Arc<dyn PurgeSink>>, budget: SliceBudget, ) -> Self
Use the same shared budget for every purge timer in an alarm.
Sourceimpl PurgeDelivery
impl PurgeDelivery
Sourcepub fn fire_with_local<'a, S: NamespaceStore>(
&'a self,
local: &'a dyn LocalInvalidation,
ctx: &'a TimerCtx<'a, S>,
timer: &'a DueTimer,
) -> BoxFuture<'a, Result<Fired, StoreError>>
pub fn fire_with_local<'a, S: NamespaceStore>( &'a self, local: &'a dyn LocalInvalidation, ctx: &'a TimerCtx<'a, S>, timer: &'a DueTimer, ) -> BoxFuture<'a, Result<Fired, StoreError>>
Use a context-local catalog reader without issuing a Durable Object self-call.